# SpikeForest

Spike sorting benchmarking system.

**This repo is under construction.**

Please see the [SpikeForest2](https://github.com/flatironinstitute/spikeforest2) repo for the time being.

## Frequently asked questions

[How can I download the SpikeForest recordings and ground truth sorting data?](./doc/download-spikeforest-data.md)

[How can I download the SpikeForest sorting outputs?](./doc/download-spikeforest-sorting-outputs.md)

[How can I visualize a SpikeForest sorting using labbox-ephys?](./doc/labbox-ephys.md)

[How can I run containerized spike sorting on my own computer?](./doc/spike-sorting.md)

## Questions with answers in progress

* What is SpikeForest?

* How do I run spike sorting on my local computer?

* What spike sorters are included in SpikeForest?

* Which spike sorting method is the best?

* How can I interact with SpikeForest data through a Python interface?

* How can I use SpikeForest data with Jupyter?

* I'd like to cite SpikeForest in a paper, how do I do that?
